"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.runtime = exports.declaration = void 0;
const locale_1 = require("../locale");
const Setting_1 = require("../models/Setting");
const getActivePluginEditorView_1 = require("../services/plugins/utils/getActivePluginEditorView");
const Logger_1 = require("@joplin/utils/Logger");
const logger = Logger_1.default.create('toggleEditorPlugin');
exports.declaration = {
    name: 'toggleEditorPlugin',
    label: () => (0, locale_1._)('Toggle editor plugin'),
    iconName: 'fas fa-eye',
};
const runtime = () => {
    return {
        execute: async (context) => {
            const shownEditorViewIds = Setting_1.default.value('plugins.shownEditorViewIds');
            const { editorPlugin, editorView } = (0, getActivePluginEditorView_1.default)(context.state.pluginService.plugins);
            if (!editorPlugin) {
                logger.warn('No editor plugin to toggle to');
                return;
            }
            const idx = shownEditorViewIds.indexOf(editorView.id);
            let hasBeenHidden = false;
            if (idx < 0) {
                shownEditorViewIds.push(editorView.id);
            }
            else {
                shownEditorViewIds.splice(idx, 1);
                hasBeenHidden = true;
            }
            logger.info('New shown editor views: ', shownEditorViewIds);
            Setting_1.default.setValue('plugins.shownEditorViewIds', shownEditorViewIds);
            if (hasBeenHidden) {
                // When the plugin editor goes from visible to hidden, we need to reload the note
                // because it may have been changed via the data API.
                context.dispatch({
                    type: 'EDITOR_NOTE_NEEDS_RELOAD',
                });
            }
        },
        enabledCondition: 'hasActivePluginEditor',
    };
};
exports.runtime = runtime;
//# sourceMappingURL=toggleEditorPlugin.js.map