"use strict";
// The goal of this class is to simplify the integration of the `joplin.views.editor` plugin logic
// in the desktop and mobile app. See here for more information:
//
// packages/lib/services/plugins/api/JoplinViewsEditor.ts
Object.defineProperty(exports, "__esModule", { value: true });
const Logger_1 = require("@joplin/utils/Logger");
const AsyncActionQueue_1 = require("../../AsyncActionQueue");
const eventManager_1 = require("../../eventManager");
const logger = Logger_1.default.create('EditorPluginHandler');
const makeNoteUpdateAction = (pluginService, shownEditorViewIds) => {
    return async () => {
        for (const viewId of shownEditorViewIds) {
            const controller = pluginService.viewControllerByViewId(viewId);
            if (controller)
                controller.emitUpdate();
        }
    };
};
class default_1 {
    constructor(pluginService) {
        this.viewUpdateAsyncQueue_ = new AsyncActionQueue_1.default(100, AsyncActionQueue_1.IntervalType.Fixed);
        this.pluginService_ = pluginService;
    }
    emitUpdate(shownEditorViewIds) {
        logger.info('emitUpdate:', shownEditorViewIds);
        this.viewUpdateAsyncQueue_.push(makeNoteUpdateAction(this.pluginService_, shownEditorViewIds));
    }
    async emitActivationCheck() {
        let filterObject = {
            activatedEditors: [],
        };
        filterObject = await eventManager_1.default.filterEmit('editorActivationCheck', filterObject);
        logger.info('emitActivationCheck: responses:', filterObject);
        for (const editor of filterObject.activatedEditors) {
            const controller = this.pluginService_.pluginById(editor.pluginId).viewController(editor.viewId);
            controller.setActive(editor.isActive);
        }
    }
}
exports.default = default_1;
//# sourceMappingURL=EditorPluginHandler.js.map